@@ -170,17 +170,17 @@ changes by earlier ones."
   :group 'lui)
 
 (defface lui-strong-face
-  '((t (:inherit bold)))
+  '((t :inherit bold))
   "Face used for strong markup."
   :group 'lui-irc-colors)
 
 (defface lui-emphasis-face
-  '((t (:inherit italic)))
+  '((t :inherit italic))
   "Face for emphasis markup."
   :group 'lui-irc-colors)
 
 (defface lui-deleted-face
-  '((t (:strike-through t)))
+  '((t :strike-through t))
   "Face for deleted messages"
   :group 'lui-irc-colors)
 
@@ -364,24 +364,24 @@ user won't see the modifications, so that's a bad idea."
   :group 'lui)
 
 (defface lui-time-stamp-face
-  '((t (:foreground "SlateBlue" :weight bold)))
+  '((t :foreground "SlateBlue" :weight bold))
   "Lui mode face used for time stamps."
   :group 'lui)
 
 (defface lui-highlight-face
   ;; Taken from `font-lock-keyword-face'
-  '((((class grayscale) (background light)) (:foreground "LightGray" :weight bold))
-    (((class grayscale) (background dark)) (:foreground "DimGray" :weight bold))
-    (((class color) (background light)) (:foreground "Purple"))
-    (((class color) (background dark)) (:foreground "Cyan1"))
-    (t (:weight bold)))
+  '((((class grayscale) (background light)) :foreground "LightGray" :weight bold)
+    (((class grayscale) (background dark)) :foreground "DimGray" :weight bold)
+    (((class color) (background light)) :foreground "Purple")
+    (((class color) (background dark)) :foreground "Cyan1")
+    (t :weight bold))
   "Lui mode face used for highlighting."
   :group 'lui)
 
 (defface lui-button-face
-  '((((class color) (background light)) (:foreground "Purple" :underline t))
-    (((class color) (background dark)) (:foreground "Cyan" :underline t))
-    (t (:underline t)))
+  '((((class color) (background light)) :foreground "Purple" :underline t)
+    (((class color) (background dark)) :foreground "Cyan" :underline t)
+    (t :underline t))
   "Default face used for LUI buttons."
   :group 'lui)
 
@@ -517,7 +517,7 @@ See `lui-scroll-behavior' for how to customize this."
 This is called from `post-command-hook'.
 
 See `lui-scroll-behavior' for how to customize this."
-  (condition-case err
+  (condition-case-unless-debug err
       (dolist (w (window-list))
         (with-current-buffer (window-buffer w)
           (when (and lui-input-marker
@@ -689,9 +689,7 @@ Otherwise, we move to the next button."
       (message "No such symbol %s" name)
       (ding))
      (t
-      (if (fboundp 'describe-symbol)
-          (describe-symbol sym)
-        (help-xref-interned sym))))))
+      (describe-symbol sym)))))
 
 (defun lui-button-pep (number)
   "Browse the PEP NUMBER."
@@ -958,7 +956,7 @@ add to the inserted message."
      (save-excursion
        (save-restriction
          (let ((inhibit-read-only t)
-               (inhibit-point-motion-hooks t))
+               (cursor-sensor-inhibit '(lui-insert-with-text-properties)))
            (widen)
            (goto-char lui-output-marker)
            (let ((beg (point))
@@ -1260,7 +1258,6 @@ If TEXT is specified, use that instead of formatting a new time stamp."
                            'lui-time-stamp t))
                (start (point)))
           (insert ts-string)
-          (add-text-properties start (1+ (point)) '(intangible t))
           (add-text-properties (1+ start) (point) '(cursor-intangible t)))))
      ;; Time stamps left
      ((eq lui-time-stamp-position 'left)
@@ -1317,10 +1314,11 @@ DELETE."
   (let ((string (if delete
                     (delete-and-extract-region beg end)
                   (buffer-substring beg end)))
-        (inhibit-point-motion-hooks t)
+        (cursor-sensor-inhibit '(lui-filter-buffer-time-stamps))
         (inhibit-read-only t))
     (with-temp-buffer
       (insert string)
+      (remove-list-of-text-properties (point-min) (point-max) '(read-only))
       (let ((start (text-property-any (point-min)
                                       (point-max)
                                       'lui-time-stamp t)))
